diff Core/HttpServer/FilesystemHttpHandler.cpp @ 59:c996319e90bc orthanc-renaming

renaming in Core
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:28:56 +0200
parents a15e90e5d6fc
children fd7b0a3e6260
line wrap: on
line diff
--- a/Core/HttpServer/FilesystemHttpHandler.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/FilesystemHttpHandler.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,12 +20,12 @@
 
 #include "FilesystemHttpHandler.h"
 
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 
 #include <boost/filesystem.hpp>
 
 
-namespace Palanthir
+namespace Orthanc
 {
   struct FilesystemHttpHandler::PImpl
   {
@@ -91,7 +91,7 @@
     if (!fs::exists(pimpl_->root_) || 
         !fs::is_directory(pimpl_->root_))
     {
-      throw PalanthirException("The path does not point to a directory");
+      throw OrthancException("The path does not point to a directory");
     }
   }
 
@@ -136,7 +136,7 @@
     }
     else
     {
-      output.SendHeader(Palanthir_HttpStatus_404_NotFound);
+      output.SendHeader(Orthanc_HttpStatus_404_NotFound);
     }
   } 
 }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium